@@ -1692,10 +1692,11 @@ netk_tasklist_activate_task_window (NetkTask * task)
 
         active_ws = netk_screen_get_active_workspace (tasklist->priv->screen);
         window_ws = netk_window_get_workspace (task->window);
-        if (window_ws && active_ws != window_ws
-            && !tasklist->priv->switch_workspace_on_unminimize)
+        if ((window_ws && active_ws != window_ws)
+            && (!tasklist->priv->switch_workspace_on_unminimize))
+        {
             netk_workspace_activate (window_ws);
-
+        }
         netk_window_activate (task->window);
     }
     else
@@ -1712,7 +1713,9 @@ netk_tasklist_activate_task_window (NetkTask * task)
 
             window_ws = netk_window_get_workspace (task->window);
             if (window_ws)
+            {
                 netk_workspace_activate (window_ws);
+            }
 
             netk_window_activate (task->window);
         }
