@@ -242,8 +242,7 @@ netk_window_class_init (NetkWindowClass * klass)
         g_signal_new ("workspace_changed", G_OBJECT_CLASS_TYPE (object_class),
                       G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (NetkWindowClass,
                                                           workspace_changed),
-                      NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
-                      0);
+                      NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
 
     signals[ICON_CHANGED] =
         g_signal_new ("icon_changed", G_OBJECT_CLASS_TYPE (object_class),
@@ -1307,23 +1306,19 @@ p_netk_window_process_property_notify (NetkWindow * window, XEvent * xevent)
     }
     else if (xevent->xproperty.atom == XA_WM_NAME
              || xevent->xproperty.atom == p_netk_atom_get ("_NET_WM_NAME")
-             || xevent->xproperty.atom ==
-             p_netk_atom_get ("_NET_WM_VISIBLE_NAME"))
+             || xevent->xproperty.atom == p_netk_atom_get ("_NET_WM_VISIBLE_NAME"))
     {
         window->priv->need_update_name = TRUE;
         queue_update (window);
     }
     else if (xevent->xproperty.atom == XA_WM_ICON_NAME
-             || xevent->xproperty.atom ==
-             p_netk_atom_get ("_NET_WM_ICON_NAME")
-             || xevent->xproperty.atom ==
-             p_netk_atom_get ("_NET_WM_VISIBLE_ICON_NAME"))
+             || xevent->xproperty.atom == p_netk_atom_get ("_NET_WM_ICON_NAME")
+             || xevent->xproperty.atom == p_netk_atom_get ("_NET_WM_VISIBLE_ICON_NAME"))
     {
         window->priv->need_update_icon_name = TRUE;
         queue_update (window);
     }
-    else if (xevent->xproperty.atom ==
-             p_netk_atom_get ("_NET_WM_ALLOWED_ACTIONS"))
+    else if (xevent->xproperty.atom == p_netk_atom_get ("_NET_WM_ALLOWED_ACTIONS"))
     {
         window->priv->need_update_actions = TRUE;
         queue_update (window);
@@ -1351,7 +1346,8 @@ p_netk_window_process_property_notify (NetkWindow * window, XEvent * xevent)
         queue_update (window);
     }
     else if (xevent->xproperty.atom == p_netk_atom_get ("_NET_WM_ICON")
-             || xevent->xproperty.atom == p_netk_atom_get ("KWM_WIN_ICON"))
+             || xevent->xproperty.atom == p_netk_atom_get ("KWM_WIN_ICON")
+             || xevent->xproperty.atom == p_netk_atom_get ("WM_HINTS"))
     {
         p_netk_icon_cache_property_changed (window->priv->icon_cache,
                                             xevent->xproperty.atom);
