@@ -1531,16 +1531,12 @@ try_pixmap_and_mask (Pixmap src_pixmap, Pixmap src_mask, GdkPixbuf ** iconp,
 
     get_pixmap_geometry (src_pixmap, &w, &h, NULL);
 
-    unscaled =
-        p_netk_gdk_pixbuf_get_from_pixmap (NULL, src_pixmap, 0, 0, 0, 0, w,
-                                           h);
+    unscaled = p_netk_gdk_pixbuf_get_from_pixmap (NULL, src_pixmap, 0, 0, 0, 0, w, h);
 
     if (unscaled && src_mask != None)
     {
         get_pixmap_geometry (src_mask, &w, &h, NULL);
-        mask =
-            p_netk_gdk_pixbuf_get_from_pixmap (NULL, src_mask, 0, 0, 0, 0, w,
-                                               h);
+        mask = p_netk_gdk_pixbuf_get_from_pixmap (NULL, src_mask, 0, 0, 0, 0, w, h);
     }
 
     p_netk_error_trap_pop ();
@@ -1561,20 +1557,16 @@ try_pixmap_and_mask (Pixmap src_pixmap, Pixmap src_mask, GdkPixbuf ** iconp,
     {
         *iconp =
             gdk_pixbuf_scale_simple (unscaled,
-                                     ideal_width >
-                                     0 ? ideal_width :
+                                     ideal_width > 0 ? ideal_width :
                                      gdk_pixbuf_get_width (unscaled),
-                                     ideal_height >
-                                     0 ? ideal_height :
+                                     ideal_height > 0 ? ideal_height :
                                      gdk_pixbuf_get_height (unscaled),
                                      GDK_INTERP_BILINEAR);
         *mini_iconp =
             gdk_pixbuf_scale_simple (unscaled,
-                                     ideal_mini_width >
-                                     0 ? ideal_mini_width :
+                                     ideal_mini_width > 0 ? ideal_mini_width :
                                      gdk_pixbuf_get_width (unscaled),
-                                     ideal_mini_height >
-                                     0 ? ideal_mini_height :
+                                     ideal_mini_height > 0 ? ideal_mini_height :
                                      gdk_pixbuf_get_height (unscaled),
                                      GDK_INTERP_BILINEAR);
 
@@ -2053,18 +2045,19 @@ p_netk_get_fallback_icons (GdkPixbuf ** iconp, int ideal_width,
                            int ideal_height, GdkPixbuf ** mini_iconp,
                            int ideal_mini_width, int ideal_mini_height)
 {
-    *iconp =
-        default_icon_at_size (ideal_width >
-                              0 ? ideal_width : DEFAULT_ICON_WIDTH,
-                              ideal_height >
-                              0 ? ideal_height : DEFAULT_ICON_HEIGHT);
+    if (iconp)
+        *iconp =
+            default_icon_at_size (ideal_width > 0 ? ideal_width : 
+                                  DEFAULT_ICON_WIDTH,
+                                  ideal_height > 0 ? ideal_height : 
+                                  DEFAULT_ICON_HEIGHT);
 
-    *mini_iconp =
-        default_icon_at_size (ideal_mini_width >
-                              0 ? ideal_mini_width : DEFAULT_MINI_ICON_WIDTH,
-                              ideal_mini_height >
-                              0 ? ideal_mini_height :
-                              DEFAULT_MINI_ICON_HEIGHT);
+    if (mini_iconp)
+        *mini_iconp =
+            default_icon_at_size (ideal_mini_width > 0 ? ideal_mini_width : 
+                                  DEFAULT_MINI_ICON_WIDTH,
+                                  ideal_mini_height > 0 ? ideal_mini_height :
+                                  DEFAULT_MINI_ICON_HEIGHT);
 }
 
 
