@@ -63,16 +63,6 @@
 #endif 
 #include <dbh.h>
 
-#ifndef HAVE_LIBXML
-#warning "mime_icons module will be disabled without libxml!"
-G_MODULE_EXPORT
-const gchar *g_module_check_init(GModule *module){
-    g_error("Cannot work with mime-icons module: libxfcegui4 constructed without libxml.");
-    return NULL;
-}
-#else
-
-
 typedef struct magic_t {
 	char *mimetype;
 	char *type;
@@ -1314,7 +1304,6 @@ void g_module_unload(GModule *module){
 	xfmime_fun = NULL;
 }
 
-#endif
 
 #if 0
 
