@@ -46,7 +46,8 @@
 
 #define VALID_KDEDIR g_getenv("KDEDIR") && strlen(g_getenv("KDEDIR"))
 #define KDEDIR g_getenv("KDEDIR"),"share","icons"
-#define HOMEDIR xfce_get_homedir(), ".icons"
+/*#define HOMEDIR xfce_get_homedir(), ".icons"*/
+#define HOMEDIR  ".icons"
 #define SERIAL 41911
 
 /* get rid of warnings generated on FreeBSD.5.2.1 
@@ -791,6 +792,7 @@ save_cache_info(gchar *theme, int size){
 	struct stat st;
 	if (stat((gchar *)list->data,&st)==0) {
 	    cache_info.basedir_sum += st.st_mtime;
+	    cache_info.basedir_sum += st.st_dev;
 	}
     }
     cache_info.basedir_sum +=SERIAL;
@@ -840,6 +842,7 @@ compare_cache_info(gchar *theme, int size){
 	struct stat st;
 	if (stat((gchar *)list->data,&st)==0) {
 	    cache_info.basedir_sum += st.st_mtime;
+	    cache_info.basedir_sum += st.st_dev;
 	}
     }
     cache_info.basedir_sum += SERIAL;
